@@ -1,15 +1,19 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 
-/* Simple box operations */
+/**
+ * SECTION:boxes
+ * @title: MetaRectangle
+ * @short_description: Simple box operations
+ */
 
-/* 
+/*
  * Copyright (C) 2005, 2006 Elijah Newren
  * [meta_rectangle_intersect() is copyright the GTK+ Team according to Havoc,
  * see gdkrectangle.c.  As far as Havoc knows, he probably wrote
  * meta_rectangle_equal(), and I'm guessing it's (C) Red Hat.  So...]
  * Copyright (C) 1995-2000  GTK+ Team
  * Copyright (C) 2002 Red Hat, Inc.
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -19,7 +23,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA
@@ -35,7 +39,7 @@
 
 /* It would make sense to use GSlice here, but until we clean up the
  * rest of this file and the internal API to use these functions, we
- * leave it using g_malloc()/g_free() for consistency.
+ * leave it using malloc()/free() for consistency.
  */
 
 MetaRectangle *
@@ -47,7 +51,7 @@ meta_rectangle_copy (const MetaRectangle *rect)
 void
 meta_rectangle_free (MetaRectangle *rect)
 {
-  g_free (rect);
+  free (rect);
 }
 
 GType
@@ -70,7 +74,7 @@ meta_rectangle_to_string (const MetaRectangle *rect,
    * Should be more than enough space.  Note that of this space, the
    * trailing \0 will be overwritten for all but the last rectangle.
    */
-  g_snprintf (output, RECT_LENGTH, "%d,%d +%d,%d", 
+  g_snprintf (output, RECT_LENGTH, "%d,%d +%d,%d",
               rect->x, rect->y, rect->width, rect->height);
 
   return output;
@@ -97,7 +101,7 @@ meta_rectangle_region_to_string (GList      *region,
   while (tmp)
     {
       MetaRectangle *rect = tmp->data;
-      g_snprintf (rect_string, RECT_LENGTH, "[%d,%d +%d,%d]", 
+      g_snprintf (rect_string, RECT_LENGTH, "[%d,%d +%d,%d]",
                   rect->x, rect->y, rect->width, rect->height);
       cur = g_stpcpy (cur, rect_string);
       tmp = tmp->next;
@@ -119,7 +123,7 @@ meta_rectangle_edge_to_string (const MetaEdge *edge,
    * Plus 2 for parenthesis, 4 for 2 more numbers, 2 more commas, and
    * 2 more spaces, for a total of 10 more.
    */
-  g_snprintf (output, EDGE_LENGTH, "[%d,%d +%d,%d], %2d, %2d", 
+  g_snprintf (output, EDGE_LENGTH, "[%d,%d +%d,%d], %2d, %2d",
               edge->rect.x, edge->rect.y, edge->rect.width, edge->rect.height,
               edge->side_type, edge->edge_type);
 
@@ -151,7 +155,7 @@ meta_rectangle_edge_list_to_string (GList      *edge_list,
     {
       MetaEdge      *edge = tmp->data;
       MetaRectangle *rect = &edge->rect;
-      g_snprintf (rect_string, EDGE_LENGTH, "([%d,%d +%d,%d], %2d, %2d)", 
+      g_snprintf (rect_string, EDGE_LENGTH, "([%d,%d +%d,%d], %2d, %2d)",
                   rect->x, rect->y, rect->width, rect->height,
                   edge->side_type, edge->edge_type);
       cur = g_stpcpy (cur, rect_string);
@@ -211,7 +215,7 @@ meta_rectangle_intersect (const MetaRectangle *src1,
   dest_y = MAX (src1->y, src2->y);
   dest_w = MIN (src1->x + src1->width, src2->x + src2->width) - dest_x;
   dest_h = MIN (src1->y + src1->height, src2->y + src2->height) - dest_y;
-  
+
   if (dest_w > 0 && dest_h > 0)
     {
       dest->x = dest_x;
@@ -321,7 +325,7 @@ gboolean
 meta_rectangle_contains_rect  (const MetaRectangle *outer_rect,
                                const MetaRectangle *inner_rect)
 {
-  return 
+  return
     inner_rect->x                      >= outer_rect->x &&
     inner_rect->y                      >= outer_rect->y &&
     inner_rect->x + inner_rect->width  <= outer_rect->x + outer_rect->width &&
@@ -340,7 +344,7 @@ meta_rectangle_resize_with_gravity (const MetaRectangle *old_rect,
    * boxes.h has a good comment, but I'm not sure if the below info is also
    * helpful on top of that (or whether it has superfluous info).
    */
- 
+
   /* These formulas may look overly simplistic at first but you can work
    * everything out with a left_frame_with, right_frame_width,
    * border_width, and old and new client area widths (instead of old total
@@ -390,7 +394,7 @@ meta_rectangle_resize_with_gravity (const MetaRectangle *old_rect,
       break;
     }
   rect->width = new_width;
-  
+
   /* Next, the y direction */
   switch (gravity)
     {
@@ -463,7 +467,7 @@ merge_spanning_rects_in_region (GList *region)
               delete_me = other;
             }
           /* If b contains a, just remove a */
-          else if (meta_rectangle_contains_rect (a, b))
+          else if (meta_rectangle_contains_rect (b, a))
             {
               delete_me = compare;
             }
@@ -522,7 +526,7 @@ merge_spanning_rects_in_region (GList *region)
                 }
 
               /* Okay, we can free it now */
-              g_free (delete_me->data);
+              free (delete_me->data);
               region = g_list_delete_link (region, delete_me);
             }
 
@@ -547,6 +551,26 @@ compare_rect_areas (gconstpointer a, gconstpointer b)
   return b_area - a_area; /* positive ret value denotes b > a, ... */
 }
 
+/* ... and another helper for get_minimal_spanning_set_for_region()... */
+static gboolean
+check_strut_align (MetaStrut *strut, const MetaRectangle *rect)
+{
+  /* Check whether @strut actually aligns to the side of @rect it claims */
+  switch (strut->side)
+    {
+    case META_SIDE_TOP:
+      return BOX_TOP (strut->rect) <= BOX_TOP (*rect);
+    case META_SIDE_BOTTOM:
+      return BOX_BOTTOM (strut->rect) >= BOX_BOTTOM (*rect);
+    case META_SIDE_LEFT:
+      return BOX_LEFT (strut->rect) <= BOX_LEFT (*rect);
+    case META_SIDE_RIGHT:
+      return BOX_RIGHT (strut->rect) >= BOX_RIGHT (*rect);
+    default:
+      return FALSE;
+    }
+}
+
 /**
  * meta_rectangle_get_minimal_spanning_set_for_region:
  * @basic_rect: Input rectangle
@@ -628,11 +652,11 @@ meta_rectangle_get_minimal_spanning_set_for_region (
   *temp_rect = *basic_rect;
   ret = g_list_prepend (NULL, temp_rect);
 
-  strut_iter = all_struts;
   for (strut_iter = all_struts; strut_iter; strut_iter = strut_iter->next)
     {
-      GList *rect_iter; 
-      MetaRectangle *strut_rect = &((MetaStrut*)strut_iter->data)->rect;
+      GList *rect_iter;
+      MetaStrut *strut = (MetaStrut*)strut_iter->data;
+      MetaRectangle *strut_rect = &strut->rect;
 
       tmp_list = ret;
       ret = NULL;
@@ -640,7 +664,9 @@ meta_rectangle_get_minimal_spanning_set_for_region (
       while (rect_iter)
         {
           MetaRectangle *rect = (MetaRectangle*) rect_iter->data;
-          if (!meta_rectangle_overlap (rect, strut_rect))
+
+          if (!meta_rectangle_overlap (strut_rect, rect) ||
+              !check_strut_align (strut, basic_rect))
             ret = g_list_prepend (ret, rect);
           else
             {
@@ -682,7 +708,7 @@ meta_rectangle_get_minimal_spanning_set_for_region (
                   temp_rect->y = new_y;
                   ret = g_list_prepend (ret, temp_rect);
                 }
-              g_free (rect);
+              free (rect);
             }
           rect_iter = rect_iter->next;
         }
@@ -751,6 +777,162 @@ meta_rectangle_expand_region_conditionally (GList     *region,
   return region;
 }
 
+LOCAL_SYMBOL void
+meta_rectangle_expand_to_snapped_borders (MetaRectangle       *rect,
+                                          const MetaRectangle *expand_to,
+                                          const GSList        *all_struts,
+                                          const GSList        *snapped_windows_as_struts,
+                                          const MetaRectangle *user_rect)
+{
+  const GSList *strut_iter;
+  gint x_c, y_c, max_x, max_y, min_x, min_y, fallback_x, fallback_y, fallback_width, fallback_height;
+  gboolean ulc = FALSE, llc = FALSE, urc = FALSE, lrc = FALSE;
+
+  x_c = BOX_CENTER_X (*user_rect);
+  y_c = BOX_TOP (*user_rect);
+  min_x = BOX_LEFT (*expand_to);
+  max_x = BOX_RIGHT (*expand_to);
+  min_y = BOX_TOP (*expand_to);
+  max_y = BOX_BOTTOM (*expand_to);
+
+  /* Iterate over all struts, find a box containing the center of the current rectangle */
+  for (strut_iter = all_struts; strut_iter; strut_iter = strut_iter->next)
+    {
+      MetaStrut *strut = (MetaStrut*) strut_iter->data;
+
+      if (!meta_rectangle_overlap (&strut->rect, expand_to))
+        continue;
+
+      if (strut->side & META_SIDE_LEFT)
+        if (BOX_RIGHT (strut->rect) > min_x)
+            min_x = BOX_RIGHT (strut->rect);
+      if (strut->side & META_SIDE_RIGHT)
+        if (BOX_LEFT (strut->rect) < max_x)
+            max_x = BOX_LEFT (strut->rect);
+      if (strut->side & META_SIDE_TOP)
+        if (BOX_BOTTOM (strut->rect) > min_y)
+            min_y = BOX_BOTTOM (strut->rect);
+      if (strut->side & META_SIDE_BOTTOM)
+        if (BOX_TOP (strut->rect) < max_y)
+            max_y = BOX_TOP (strut->rect);
+    } /* end loop over struts */
+
+/* store safe fallback values if we end up with an impossible situation at the end */
+  fallback_x = min_x;
+  fallback_y = min_y;
+  fallback_width = max_x - min_x;
+  fallback_height = max_y - min_y;
+
+  for (strut_iter = snapped_windows_as_struts; strut_iter; strut_iter = strut_iter->next)
+    {
+
+      MetaStrut *strut = (MetaStrut*) strut_iter->data;
+
+      if (strut->side == (META_SIDE_LEFT | META_SIDE_TOP) ||
+          strut->side == (META_SIDE_LEFT | META_SIDE_BOTTOM) ||
+          strut->side == (META_SIDE_RIGHT | META_SIDE_TOP) ||
+          strut->side == (META_SIDE_RIGHT | META_SIDE_BOTTOM)) {
+        ulc = ulc || strut->side == (META_SIDE_LEFT | META_SIDE_TOP);
+        llc = llc || strut->side == (META_SIDE_LEFT | META_SIDE_BOTTOM);
+        urc = urc || strut->side == (META_SIDE_RIGHT | META_SIDE_TOP);
+        lrc = lrc || strut->side == (META_SIDE_RIGHT | META_SIDE_BOTTOM);
+        continue;
+      }
+      if (strut->side & META_SIDE_LEFT)
+        if (BOX_RIGHT (strut->rect) > min_x)
+            min_x = BOX_RIGHT (strut->rect);
+      if (strut->side & META_SIDE_RIGHT)
+        if (BOX_LEFT (strut->rect) < max_x)
+            max_x = BOX_LEFT (strut->rect);
+      if (strut->side & META_SIDE_TOP)
+        if (BOX_BOTTOM (strut->rect) > min_y)
+            min_y = BOX_BOTTOM (strut->rect);
+      if (strut->side & META_SIDE_BOTTOM)
+        if (BOX_TOP (strut->rect) < max_y)
+            max_y = BOX_TOP (strut->rect);
+    } /* end loop over struts */
+
+  for (strut_iter = snapped_windows_as_struts; strut_iter; strut_iter = strut_iter->next)
+    {
+      MetaStrut *strut = (MetaStrut*) strut_iter->data;
+
+      if (strut->side == (META_SIDE_LEFT | META_SIDE_TOP)) {
+        if (llc) {
+            min_x = BOX_RIGHT (strut->rect);
+        }
+        if (urc) {
+            min_y = BOX_BOTTOM (strut->rect);
+        }
+        if (!llc && !urc) {
+            if (x_c > BOX_RIGHT (strut->rect) &&
+                y_c < BOX_BOTTOM (strut->rect))
+                min_x = BOX_RIGHT (strut->rect);
+            else
+                min_y = BOX_BOTTOM (strut->rect);
+        }
+      } else if (strut->side == (META_SIDE_LEFT | META_SIDE_BOTTOM)) {
+        if (ulc) {
+            min_x = BOX_RIGHT (strut->rect);
+        }
+        if (lrc) {
+            max_y = BOX_TOP (strut->rect);
+        }
+        if (!ulc && !lrc) {
+            if (x_c > BOX_RIGHT (strut->rect) &&
+                y_c > BOX_TOP (strut->rect)) {
+                min_x = BOX_RIGHT (strut->rect);
+            } else {
+                max_y = BOX_TOP (strut->rect);
+            }
+        }
+      } else if (strut->side == (META_SIDE_RIGHT | META_SIDE_TOP)) {
+        if (lrc) {
+            max_x = BOX_LEFT (strut->rect);
+        }
+        if (ulc) {
+            min_y = BOX_BOTTOM (strut->rect);
+        }
+        if (!lrc && !ulc) {
+            if (x_c < BOX_LEFT (strut->rect) &&
+                y_c < BOX_BOTTOM (strut->rect))
+                max_x = BOX_LEFT (strut->rect);
+            else
+                min_y = BOX_BOTTOM (strut->rect);
+        }
+      } else if (strut->side == (META_SIDE_RIGHT | META_SIDE_BOTTOM)) {
+        if (urc) {
+            max_x = BOX_LEFT (strut->rect);
+        }
+        if (llc) {
+            max_y = BOX_TOP (strut->rect);
+        }
+        if (!urc && !llc) {
+            if (x_c < BOX_LEFT (strut->rect) &&
+                y_c > BOX_TOP (strut->rect))
+                max_x = BOX_LEFT (strut->rect);
+            else
+                max_y = BOX_TOP (strut->rect);
+        }
+      } else {
+        continue;
+      }
+    } /* end loop over struts */
+
+  rect->x = min_x;
+  rect->y = min_y;
+  rect->width = max_x - min_x;
+  rect->height = max_y - min_y;
+
+  if (rect->width <= 0) {
+    rect->x = fallback_x;
+    rect->width = fallback_width;
+  }
+  if (rect->height <= 0) {
+    rect->y = fallback_y;
+    rect->height = fallback_height;
+  }
+}
+
 LOCAL_SYMBOL void
 meta_rectangle_expand_to_avoiding_struts (MetaRectangle       *rect,
                                           const MetaRectangle *expand_to,
@@ -766,7 +948,7 @@ meta_rectangle_expand_to_avoiding_struts (MetaRectangle       *rect,
    */
   g_assert ((direction == META_DIRECTION_HORIZONTAL) ^
             (direction == META_DIRECTION_VERTICAL  ));
- 
+
   if (direction == META_DIRECTION_HORIZONTAL)
     {
       rect->x      = expand_to->x;
@@ -778,12 +960,12 @@ meta_rectangle_expand_to_avoiding_struts (MetaRectangle       *rect,
       rect->height = expand_to->height;
     }
 
- 
+
   /* Run over all struts */
   for (strut_iter = all_struts; strut_iter; strut_iter = strut_iter->next)
     {
       MetaStrut *strut = (MetaStrut*) strut_iter->data;
- 
+
       /* Skip struts that don't overlap */
       if (!meta_rectangle_overlap (&strut->rect, rect))
         continue;
@@ -824,8 +1006,8 @@ meta_rectangle_expand_to_avoiding_struts (MetaRectangle       *rect,
 LOCAL_SYMBOL void
 meta_rectangle_free_list_and_elements (GList *filled_list)
 {
-  g_list_foreach (filled_list, 
-                  (void (*)(gpointer,gpointer))&g_free, /* ew, for ugly */
+  g_list_foreach (filled_list,
+                  (void (*)(gpointer,gpointer))&free, /* ew, for ugly */
                   NULL);
   g_list_free (filled_list);
 }
@@ -902,20 +1084,20 @@ meta_rectangle_clamp_to_fit_into_region (const GList         *spanning_rects,
     {
       MetaRectangle *compare_rect = temp->data;
       int            maximal_overlap_amount_for_compare;
-      
+
       /* If x is fixed and the entire width of rect doesn't fit in compare,
        * skip this rectangle.
        */
       if ((fixed_directions & FIXED_DIRECTION_X) &&
-          (compare_rect->x > rect->x || 
+          (compare_rect->x > rect->x ||
            compare_rect->x + compare_rect->width < rect->x + rect->width))
         continue;
-        
+
       /* If y is fixed and the entire height of rect doesn't fit in compare,
        * skip this rectangle.
        */
       if ((fixed_directions & FIXED_DIRECTION_Y) &&
-          (compare_rect->y > rect->y || 
+          (compare_rect->y > rect->y ||
            compare_rect->y + compare_rect->height < rect->y + rect->height))
         continue;
 
@@ -972,20 +1154,20 @@ meta_rectangle_clip_to_region (const GList         *spanning_rects,
       MetaRectangle *compare_rect = temp->data;
       MetaRectangle  overlap;
       int            maximal_overlap_amount_for_compare;
-     
+
       /* If x is fixed and the entire width of rect doesn't fit in compare,
        * skip the rectangle.
        */
       if ((fixed_directions & FIXED_DIRECTION_X) &&
-          (compare_rect->x > rect->x || 
+          (compare_rect->x > rect->x ||
            compare_rect->x + compare_rect->width < rect->x + rect->width))
         continue;
-        
+
       /* If y is fixed and the entire height of rect doesn't fit in compare,
        * skip the rectangle.
        */
       if ((fixed_directions & FIXED_DIRECTION_Y) &&
-          (compare_rect->y > rect->y || 
+          (compare_rect->y > rect->y ||
            compare_rect->y + compare_rect->height < rect->y + rect->height))
         continue;
 
@@ -1045,26 +1227,26 @@ meta_rectangle_shove_into_region (const GList         *spanning_rects,
   /* First, find best rectangle from spanning_rects to which we will shove
    * rect into.
    */
-  
+
   for (temp = spanning_rects; temp; temp = temp->next)
     {
       MetaRectangle *compare_rect = temp->data;
       int            maximal_overlap_amount_for_compare;
       int            dist_to_compare;
-      
+
       /* If x is fixed and the entire width of rect doesn't fit in compare,
        * skip this rectangle.
        */
       if ((fixed_directions & FIXED_DIRECTION_X) &&
-          (compare_rect->x > rect->x || 
+          (compare_rect->x > rect->x ||
            compare_rect->x + compare_rect->width < rect->x + rect->width))
         continue;
-        
+
       /* If y is fixed and the entire height of rect doesn't fit in compare,
        * skip this rectangle.
        */
       if ((fixed_directions & FIXED_DIRECTION_Y) &&
-          (compare_rect->y > rect->y || 
+          (compare_rect->y > rect->y ||
            compare_rect->y + compare_rect->height < rect->y + rect->height))
         continue;
 
@@ -1220,7 +1402,7 @@ meta_rectangle_edge_aligns (const MetaRectangle *rect, const MetaEdge *edge)
 }
 
 static GList*
-get_rect_minus_overlap (const GList   *rect_in_list, 
+get_rect_minus_overlap (const GList   *rect_in_list,
                         MetaRectangle *overlap)
 {
   MetaRectangle *temp;
@@ -1265,7 +1447,7 @@ get_rect_minus_overlap (const GList   *rect_in_list,
 }
 
 static GList*
-replace_rect_with_list (GList *old_element, 
+replace_rect_with_list (GList *old_element,
                         GList *new_list)
 {
   GList *ret;
@@ -1294,7 +1476,7 @@ replace_rect_with_list (GList *old_element,
     }
 
   /* Free the old_element and return the appropriate "next" point */
-  g_free (old_element->data);
+  free (old_element->data);
   g_list_free_1 (old_element);
   return ret;
 }
@@ -1322,7 +1504,7 @@ get_disjoint_strut_rect_list_in_region (const GSList        *old_struts,
       if (meta_rectangle_intersect (copy, region, copy))
         strut_rects = g_list_prepend (strut_rects, copy);
       else
-        g_free (copy);
+        free (copy);
 
       old_struts = old_struts->next;
     }
@@ -1477,7 +1659,7 @@ rectangle_and_edge_intersection (const MetaRectangle *rect,
   overlap->edge_type = -1;
   overlap->side_type = -1;
 
-  /* Figure out what the intersection is */  
+  /* Figure out what the intersection is */
   result->x = MAX (rect->x, rect2->x);
   result->y = MAX (rect->y, rect2->y);
   result->width  = MIN (BOX_RIGHT (*rect),  BOX_RIGHT (*rect2))  - result->x;
@@ -1548,7 +1730,7 @@ rectangle_and_edge_intersection (const MetaRectangle *rect,
  * TOP<->BOTTOM).
  */
 static GList*
-add_edges (GList               *cur_edges, 
+add_edges (GList               *cur_edges,
            const MetaRectangle *rect,
            gboolean             rect_is_internal)
 {
@@ -1562,23 +1744,23 @@ add_edges (GList               *cur_edges,
       switch (i)
         {
         case 0:
-          temp_edge->side_type = 
+          temp_edge->side_type =
             rect_is_internal ? META_SIDE_LEFT : META_SIDE_RIGHT;
           temp_edge->rect.width = 0;
           break;
         case 1:
-          temp_edge->side_type = 
+          temp_edge->side_type =
             rect_is_internal ? META_SIDE_RIGHT : META_SIDE_LEFT;
           temp_edge->rect.x     += temp_edge->rect.width;
           temp_edge->rect.width  = 0;
           break;
         case 2:
-          temp_edge->side_type = 
+          temp_edge->side_type =
             rect_is_internal ? META_SIDE_TOP : META_SIDE_BOTTOM;
           temp_edge->rect.height = 0;
           break;
         case 3:
-          temp_edge->side_type = 
+          temp_edge->side_type =
             rect_is_internal ? META_SIDE_BOTTOM : META_SIDE_TOP;
           temp_edge->rect.y      += temp_edge->rect.height;
           temp_edge->rect.height  = 0;
@@ -1595,8 +1777,8 @@ add_edges (GList               *cur_edges,
  * edges to cur_list.  Return cur_list when finished.
  */
 static GList*
-split_edge (GList *cur_list, 
-            const MetaEdge *old_edge, 
+split_edge (GList *cur_list,
+            const MetaEdge *old_edge,
             const MetaEdge *remove)
 {
   MetaEdge *temp_edge;
@@ -1655,7 +1837,7 @@ split_edge (GList *cur_list,
  * if and how rect and edge intersect.
  */
 static void
-fix_up_edges (MetaRectangle *rect,         MetaEdge *edge, 
+fix_up_edges (MetaRectangle *rect,         MetaEdge *edge,
               GList         **strut_edges, GList    **edge_splits,
               gboolean      *edge_needs_removal)
 {
@@ -1690,7 +1872,7 @@ fix_up_edges (MetaRectangle *rect,         MetaEdge *edge,
 
               /* Delete the old one */
               tmp = tmp->next;
-              g_free (cur);
+              free (cur);
               *strut_edges = g_list_delete_link (*strut_edges, delete_me);
             }
           else
@@ -1753,7 +1935,7 @@ meta_rectangle_remove_intersections_with_boxes_from_edges (
                   edges = split_edge (edges, edge, &overlap);
 
                   /* Now free the edge... */
-                  g_free (edge);
+                  free (edge);
                   edges = g_list_delete_link (edges, delete_me);
                 }
             }
@@ -1779,7 +1961,7 @@ meta_rectangle_find_onscreen_edges (const MetaRectangle *basic_rect,
 {
   GList        *ret;
   GList        *fixed_strut_rects;
-  GList        *edge_iter; 
+  GList        *edge_iter;
   const GList  *strut_rect_iter;
 
   /* The algorithm is basically as follows:
@@ -1819,7 +2001,7 @@ meta_rectangle_find_onscreen_edges (const MetaRectangle *basic_rect,
           GList *splits_of_cur_edge = NULL;
           gboolean edge_needs_removal = FALSE;
 
-          fix_up_edges (strut_rect,       cur_edge, 
+          fix_up_edges (strut_rect,       cur_edge,
                         &new_strut_edges, &splits_of_cur_edge,
                         &edge_needs_removal);
 
@@ -1828,7 +2010,7 @@ meta_rectangle_find_onscreen_edges (const MetaRectangle *basic_rect,
               /* Delete the old edge */
               GList *delete_me = edge_iter;
               edge_iter = edge_iter->next;
-              g_free (cur_edge);
+              free (cur_edge);
               ret = g_list_delete_link (ret, delete_me);
 
               /* Add the new split parts of the edge */
@@ -1983,7 +2165,7 @@ meta_rectangle_find_nonintersected_monitor_edges (
   for (; all_struts; all_struts = all_struts->next)
     temp_rects = g_slist_prepend (temp_rects,
                                   &((MetaStrut*)all_struts->data)->rect);
-  ret = meta_rectangle_remove_intersections_with_boxes_from_edges (ret, 
+  ret = meta_rectangle_remove_intersections_with_boxes_from_edges (ret,
                                                                    temp_rects);
   g_slist_free (temp_rects);
 
