@@ -30,22 +30,6 @@
 
 /* The icon-reading code is also in libwnck, please sync bugfixes */
 
-static void
-get_fallback_icons (MetaScreen     *screen,
-                    GdkPixbuf     **iconp,
-                    int             ideal_width,
-                    int             ideal_height,
-                    GdkPixbuf     **mini_iconp,
-                    int             ideal_mini_width,
-                    int             ideal_mini_height)
-{
-  /* we don't scale, should be fixed if we ever un-hardcode the icon
-   * size
-   */
-  *iconp = meta_ui_get_default_window_icon (screen->ui);
-  *mini_iconp = meta_ui_get_default_mini_icon (screen->ui);
-}
-
 static gboolean
 find_largest_sizes (gulong *data,
                     gulong  nitems,
@@ -211,14 +195,9 @@ read_rgb_icon (MetaDisplay   *display,
                Window         xwindow,
                int            ideal_width,
                int            ideal_height,
-               int            ideal_mini_width,
-               int            ideal_mini_height,
                int           *width,
                int           *height,
-               guchar       **pixdata,
-               int           *mini_width,
-               int           *mini_height,
-               guchar       **mini_pixdata)
+               guchar       **pixdata)
 {
   Atom type;
   int format;
@@ -228,8 +207,6 @@ read_rgb_icon (MetaDisplay   *display,
   guchar *data;
   gulong *best;
   int w, h;
-  gulong *best_mini;
-  int mini_w, mini_h;
   gulong *data_as_long;
 
   meta_error_trap_push_with_return (display);
@@ -263,22 +240,10 @@ read_rgb_icon (MetaDisplay   *display,
       return FALSE;
     }
 
-  if (!find_best_size (data_as_long, nitems,
-                       ideal_mini_width, ideal_mini_height,
-                       &mini_w, &mini_h, &best_mini))
-    {
-      XFree (data);
-      return FALSE;
-    }
-
   *width = w;
   *height = h;
 
-  *mini_width = mini_w;
-  *mini_height = mini_h;
-
   argbdata_to_pixdata (best, w * h, pixdata);
-  argbdata_to_pixdata (best_mini, mini_w * mini_h, mini_pixdata);
 
   XFree (data);
 
@@ -288,7 +253,7 @@ read_rgb_icon (MetaDisplay   *display,
 static void
 free_pixels (guchar *pixels, gpointer data)
 {
-  g_free (pixels);
+  free (pixels);
 }
 
 static void
@@ -406,10 +371,7 @@ try_pixmap_and_mask (MetaDisplay *display,
                      Pixmap       src_mask,
                      GdkPixbuf  **iconp,
                      int          ideal_width,
-                     int          ideal_height,
-                     GdkPixbuf  **mini_iconp,
-                     int          ideal_mini_width,
-                     int          ideal_mini_height)
+                     int          ideal_height)
 {
   GdkPixbuf *unscaled = NULL;
   GdkPixbuf *mask = NULL;
@@ -464,24 +426,15 @@ try_pixmap_and_mask (MetaDisplay *display,
                                  ideal_height > 0 ? ideal_height :
                                  gdk_pixbuf_get_height (unscaled),
                                  GDK_INTERP_BILINEAR);
-      *mini_iconp =
-        gdk_pixbuf_scale_simple (unscaled,
-                                 ideal_mini_width > 0 ? ideal_mini_width :
-                                 gdk_pixbuf_get_width (unscaled),
-                                 ideal_mini_height > 0 ? ideal_mini_height :
-                                 gdk_pixbuf_get_height (unscaled),
-                                 GDK_INTERP_BILINEAR);
 
       g_object_unref (G_OBJECT (unscaled));
-      
-      if (*iconp && *mini_iconp)
+
+      if (*iconp)
         return TRUE;
       else
         {
           if (*iconp)
             g_object_unref (G_OBJECT (*iconp));
-          if (*mini_iconp)
-            g_object_unref (G_OBJECT (*mini_iconp));
           return FALSE;
         }
     }
@@ -544,14 +497,7 @@ meta_icon_cache_init (MetaIconCache *icon_cache)
   icon_cache->origin = USING_NO_ICON;
   icon_cache->prev_pixmap = None;
   icon_cache->prev_mask = None;
-#if 0
-  icon_cache->icon = NULL;
-  icon_cache->mini_icon = NULL;
-  icon_cache->ideal_width = -1; /* won't be a legit width */
-  icon_cache->ideal_height = -1;
-  icon_cache->ideal_mini_width = -1;
-  icon_cache->ideal_mini_height = -1;
-#endif
+
   icon_cache->want_fallback = TRUE;
   icon_cache->wm_hints_dirty = TRUE;
   icon_cache->kwm_win_icon_dirty = TRUE;
@@ -571,7 +517,7 @@ clear_icon_cache (MetaIconCache *icon_cache,
     g_object_unref (G_OBJECT (icon_cache->mini_icon));
   icon_cache->mini_icon = NULL;
 #endif
-  
+
   icon_cache->origin = USING_NO_ICON;
 
   if (dirty_all)
@@ -628,24 +574,11 @@ meta_icon_cache_get_icon_invalidated (MetaIconCache *icon_cache)
 static void
 replace_cache (MetaIconCache *icon_cache,
                IconOrigin     origin,
-               GdkPixbuf     *new_icon,
-               GdkPixbuf     *new_mini_icon)
+               GdkPixbuf     *new_icon)
 {
   clear_icon_cache (icon_cache, FALSE);
 
   icon_cache->origin = origin;
-
-#if 0
-  if (new_icon)
-    g_object_ref (G_OBJECT (new_icon));
-
-  icon_cache->icon = new_icon;
-
-  if (new_mini_icon)
-    g_object_ref (G_OBJECT (new_mini_icon));
-
-  icon_cache->mini_icon = new_mini_icon;
-#endif
 }
 
 static GdkPixbuf*
@@ -657,13 +590,13 @@ scaled_from_pixdata (guchar *pixdata,
 {
   GdkPixbuf *src;
   GdkPixbuf *dest;
-  
+
   src = gdk_pixbuf_new_from_data (pixdata,
                                   GDK_COLORSPACE_RGB,
                                   TRUE,
                                   8,
                                   w, h, w * 4,
-                                  free_pixels, 
+                                  free_pixels,
                                   NULL);
 
   if (src == NULL)
@@ -675,7 +608,7 @@ scaled_from_pixdata (guchar *pixdata,
       int size;
 
       size = MAX (w, h);
-      
+
       tmp = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, size, size);
 
       if (tmp)
@@ -684,16 +617,16 @@ scaled_from_pixdata (guchar *pixdata,
 	  gdk_pixbuf_copy_area (src, 0, 0, w, h,
 				tmp,
 				(size - w) / 2, (size - h) / 2);
-	  
+
 	  g_object_unref (src);
 	  src = tmp;
 	}
     }
-  
+
   if (w != new_w || h != new_h)
     {
       dest = gdk_pixbuf_scale_simple (src, new_w, new_h, GDK_INTERP_BILINEAR);
-      
+
       g_object_unref (G_OBJECT (src));
     }
   else
@@ -712,15 +645,10 @@ meta_read_icons (MetaScreen     *screen,
                  Pixmap          wm_hints_mask,
                  GdkPixbuf     **iconp,
                  int             ideal_width,
-                 int             ideal_height,
-                 GdkPixbuf     **mini_iconp,
-                 int             ideal_mini_width,
-                 int             ideal_mini_height)
+                 int             ideal_height)
 {
   guchar *pixdata;
   int w, h;
-  guchar *mini_pixdata;
-  int mini_w, mini_h;
   Pixmap pixmap;
   Pixmap mask;
 
@@ -729,23 +657,8 @@ meta_read_icons (MetaScreen     *screen,
   g_return_val_if_fail (icon_cache != NULL, FALSE);
 
   *iconp = NULL;
-  *mini_iconp = NULL;
 
-#if 0
-  if (ideal_width != icon_cache->ideal_width ||
-      ideal_height != icon_cache->ideal_height ||
-      ideal_mini_width != icon_cache->ideal_mini_width ||
-      ideal_mini_height != icon_cache->ideal_mini_height)
-    clear_icon_cache (icon_cache, TRUE);
-
-  icon_cache->ideal_width = ideal_width;
-  icon_cache->ideal_height = ideal_height;
-  icon_cache->ideal_mini_width = ideal_mini_width;
-  icon_cache->ideal_mini_height = ideal_mini_height;
-#endif
-  
-  if (!meta_icon_cache_get_icon_invalidated (icon_cache))
-    return FALSE; /* we have no new info to use */
+  clear_icon_cache (icon_cache, TRUE);
 
   pixdata = NULL;
 
@@ -766,29 +679,21 @@ meta_read_icons (MetaScreen     *screen,
 
       if (read_rgb_icon (screen->display, xwindow,
                          ideal_width, ideal_height,
-                         ideal_mini_width, ideal_mini_height,
-                         &w, &h, &pixdata,
-                         &mini_w, &mini_h, &mini_pixdata))
+                         &w, &h, &pixdata))
         {
           *iconp = scaled_from_pixdata (pixdata, w, h,
                                         ideal_width, ideal_height);
 
-          *mini_iconp = scaled_from_pixdata (mini_pixdata, mini_w, mini_h,
-                                             ideal_mini_width, ideal_mini_height);
-
-          if (*iconp && *mini_iconp)
+          if (*iconp)
             {
-              replace_cache (icon_cache, USING_NET_WM_ICON,
-                             *iconp, *mini_iconp);
-              
+              replace_cache (icon_cache, USING_NET_WM_ICON, *iconp);
+
               return TRUE;
             }
           else
             {
               if (*iconp)
                 g_object_unref (G_OBJECT (*iconp));
-              if (*mini_iconp)
-                g_object_unref (G_OBJECT (*mini_iconp));
             }
         }
     }
@@ -811,14 +716,12 @@ meta_read_icons (MetaScreen     *screen,
         {
           if (try_pixmap_and_mask (screen->display,
                                    pixmap, mask,
-                                   iconp, ideal_width, ideal_height,
-                                   mini_iconp, ideal_mini_width, ideal_mini_height))
+                                   iconp, ideal_width, ideal_height))
             {
               icon_cache->prev_pixmap = pixmap;
               icon_cache->prev_mask = mask;
 
-              replace_cache (icon_cache, USING_WM_HINTS,
-                             *iconp, *mini_iconp);
+              replace_cache (icon_cache, USING_WM_HINTS, *iconp);
 
               return TRUE;
             }
@@ -837,34 +740,22 @@ meta_read_icons (MetaScreen     *screen,
           pixmap != None)
         {
           if (try_pixmap_and_mask (screen->display, pixmap, mask,
-                                   iconp, ideal_width, ideal_height,
-                                   mini_iconp, ideal_mini_width, ideal_mini_height))
+                                   iconp, ideal_width, ideal_height))
             {
               icon_cache->prev_pixmap = pixmap;
               icon_cache->prev_mask = mask;
 
-              replace_cache (icon_cache, USING_KWM_WIN_ICON,
-                             *iconp, *mini_iconp);
+              replace_cache (icon_cache, USING_KWM_WIN_ICON, *iconp);
 
               return TRUE;
             }
         }
     }
 
-  if (icon_cache->want_fallback &&
-      icon_cache->origin < USING_FALLBACK_ICON)
+  if (icon_cache->origin < USING_FALLBACK_ICON)
     {
-      get_fallback_icons (screen,
-                          iconp,
-                          ideal_width,
-                          ideal_height,
-                          mini_iconp,
-                          ideal_mini_width,
-                          ideal_mini_height);
+      replace_cache (icon_cache, USING_FALLBACK_ICON, *iconp);
 
-      replace_cache (icon_cache, USING_FALLBACK_ICON,
-                     *iconp, *mini_iconp);
-      
       return TRUE;
     }
 
