@@ -2,10 +2,10 @@
 
 /* Muffin main() */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2006 Elijah Newren
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -15,7 +15,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA
@@ -26,12 +26,12 @@
  * SECTION:main
  * @title: Main
  * @short_description: Program startup.
- * 
+ *
  * Functions which parse the command-line arguments, create the display,
  * kick everything off and then close down Muffin when it's time to go.
  *
- * 
- * 
+ *
+ *
  * Muffin - a boring window manager for the adult in you
  *
  * Many window managers are like Marshmallow Froot Loops; Muffin
@@ -49,7 +49,7 @@
 
 #include <config.h>
 #include <meta/main.h>
-#include <meta/util.h>
+#include "util-private.h"
 #include "display-private.h"
 #include <meta/errors.h>
 #include "ui.h"
@@ -74,7 +74,10 @@
 #include <unistd.h>
 
 #include <clutter/clutter.h>
-#include <clutter/x11/clutter-x11.h>
+#include "clutter/x11/clutter-x11.h"
+#include "cogl/cogl.h"
+#include "cogl/cogl-xlib.h"
+#include "cogl/winsys/cogl-winsys-glx-private.h"
 #include <GL/gl.h>
 
 #ifdef HAVE_INTROSPECTION
@@ -115,6 +118,33 @@ log_handler (const gchar   *log_domain,
   meta_print_backtrace ();
 }
 
+static void
+glib_debug_log_handler (const gchar   *log_domain,
+             GLogLevelFlags log_level,
+             const gchar   *message,
+             gpointer       user_data)
+{
+  guint i;
+  const gchar *forbidden[] = {
+    "posix_spawn",
+    "setenv()/putenv()",
+    "unsetenv()"
+  };
+
+  for (i = 0; i < G_N_ELEMENTS (forbidden); i++)
+    {
+      if (g_str_has_prefix (message, forbidden[i]))
+        {
+          return;
+        }
+    }
+
+  log_handler (log_domain,
+               log_level,
+               message,
+               user_data);
+}
+
 /*
  * Prints a list of which configure script options were used to
  * build this copy of Muffin. This is actually always called
@@ -182,7 +212,7 @@ meta_print_self_identity (void)
   g_date_strftime (buf, sizeof (buf), "%x", &d);
   meta_verbose ("Muffin version %s running on %s\n",
     VERSION, buf);
-  
+
   /* Locale and encoding. */
   g_get_charset (&charset);
   meta_verbose ("Running in locale \"%s\" with encoding \"%s\"\n",
@@ -279,7 +309,7 @@ meta_get_option_context (void)
  * of the queue and dispatching them before we block for new events.
  */
 
-static gboolean 
+static gboolean
 event_prepare (GSource    *source,
                gint       *timeout_)
 {
@@ -288,7 +318,7 @@ event_prepare (GSource    *source,
   return clutter_events_pending ();
 }
 
-static gboolean 
+static gboolean
 event_check (GSource *source)
 {
   return clutter_events_pending ();
@@ -315,14 +345,34 @@ static GSourceFuncs event_funcs = {
 static void
 meta_clutter_init (void)
 {
-  clutter_x11_set_display (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()));
+  gboolean threaded_swap = meta_prefs_get_threaded_swap ();
+  Display *xdisplay = GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
+  clutter_x11_set_display (xdisplay);
+
   clutter_x11_disable_event_retrieval ();
-  
+
   if (CLUTTER_INIT_SUCCESS == clutter_init (NULL, NULL))
     {
       GSource *source = g_source_new (&event_funcs, sizeof (GSource));
       g_source_attach (source, NULL);
       g_source_unref (source);
+
+      if (threaded_swap)
+        {
+          CoglRenderer *renderer = cogl_renderer_new ();
+          cogl_renderer_set_custom_winsys (renderer, _cogl_winsys_glx_get_vtable (), NULL);
+          cogl_xlib_renderer_set_foreign_display (renderer, xdisplay);
+
+          cogl_xlib_renderer_request_reset_on_video_memory_purge (renderer, TRUE);
+
+          /* Set up things so that if the INTEL_swap_event extension is not present,
+            * but the driver is known to have good thread support, we use an extra
+            * thread and call glXWaitVideoSync() in the thread. This allows idles
+            * to work properly, even when Muffin is constantly redrawing new frames;
+            * otherwise, without INTEL_swap_event, we'll just block in glXSwapBuffers().
+            */
+          cogl_xlib_renderer_set_threaded_swap_wait_enabled (renderer, TRUE);
+        }
     }
   else
     {
@@ -393,6 +443,13 @@ meta_init (void)
   struct sigaction act;
   sigset_t empty_mask;
   GIOChannel *channel;
+  gboolean threaded_swap = meta_prefs_get_threaded_swap ();
+
+  /* XInitThreads() is needed to use the "threaded swap wait" functionality
+   * in Cogl. We call it here to hopefully call it before any other use of XLib.
+   */
+  if (threaded_swap)
+    XInitThreads();
 
   sigemptyset (&empty_mask);
   act.sa_handler = SIG_IGN;
@@ -433,7 +490,7 @@ meta_init (void)
                     g_get_home_dir ());
 
   meta_print_self_identity ();
-  
+
 #ifdef HAVE_INTROSPECTION
   g_irepository_prepend_search_path (MUFFIN_PKGLIBDIR);
 #endif
@@ -441,22 +498,35 @@ meta_init (void)
   meta_set_syncing (opt_sync || (g_getenv ("MUFFIN_SYNC") != NULL));
 
   meta_select_display (opt_display_name);
-  
+
   if (opt_replace_wm)
     meta_set_replace_current_wm (TRUE);
 
   if (opt_save_file && opt_client_id)
     meta_fatal ("Can't specify both SM save file and SM client id\n");
-  
+
   meta_main_loop = g_main_loop_new (NULL, FALSE);
-  
+
   meta_ui_init ();
 
+  /*
+   * Disable some variables that cause rendering issues with private Clutter,
+   * except when software rendering is explicitly set by Cinnamon.
+   */
+  g_unsetenv ("CLUTTER_VBLANK");
+
+  if (g_getenv ("CINNAMON_SOFTWARE_RENDERING") == NULL)
+    g_unsetenv ("CLUTTER_PAINT");
+
+  /* Load prefs */
+  meta_prefs_init ();
+  _clutter_set_sync_method (meta_prefs_get_sync_method ());
+
   /*
    * Clutter can only be initialized after the UI.
    */
   meta_clutter_init ();
-  
+
   const char *renderer = (const char *) glGetString (GL_RENDERER);
   if (strstr (renderer, "llvmpipe") ||
       strstr (renderer, "Rasterizer") ||
@@ -480,15 +550,23 @@ int
 meta_run (void)
 {
   const gchar *log_domains[] = {
-    NULL, G_LOG_DOMAIN, "Gtk", "Gdk", "GLib",
+    NULL, G_LOG_DOMAIN, "Gtk", "Gdk",
     "Pango", "GLib-GObject", "GThread"
   };
   guint i;
 
-  /* Load prefs */
-  meta_prefs_init ();
   meta_prefs_add_listener (prefs_changed_callback, NULL);
 
+  // Intercept GLib debug level
+  g_log_set_handler ("GLib",
+                     G_LOG_LEVEL_DEBUG,
+                     glib_debug_log_handler, NULL);
+
+  // Direct all but debug to the normal handler
+  g_log_set_handler ("GLib",
+                     (G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION) & ~G_LOG_LEVEL_DEBUG,
+                     log_handler, NULL);
+
   for (i=0; i<G_N_ELEMENTS(log_domains); i++)
     g_log_set_handler (log_domains[i],
                        G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
@@ -496,16 +574,16 @@ meta_run (void)
 
   if (g_getenv ("MUFFIN_G_FATAL_WARNINGS") != NULL)
     g_log_set_always_fatal (G_LOG_LEVEL_MASK);
-  
+
   meta_ui_set_current_theme (meta_prefs_get_theme (), FALSE);
 
   if (!meta_ui_have_a_theme ())
     {
       meta_ui_set_current_theme ("Default", FALSE);
-      meta_warning (_("Could not find theme %s. Falling back to default theme."), meta_prefs_get_theme ());
+      meta_warning ("Could not find theme %s. Falling back to default theme.", meta_prefs_get_theme ());
     }
- 
- 
+
+
   /* Connect to SM as late as possible - but before managing display,
    * or we might try to manage a window before we have the session
    * info
@@ -515,9 +593,9 @@ meta_run (void)
       if (opt_client_id == NULL)
         {
           const gchar *desktop_autostart_id;
-  
+
           desktop_autostart_id = g_getenv ("DESKTOP_AUTOSTART_ID");
- 
+
           if (desktop_autostart_id != NULL)
             opt_client_id = g_strdup (desktop_autostart_id);
         }
@@ -531,13 +609,13 @@ meta_run (void)
   /* Free memory possibly allocated by the argument parsing which are
    * no longer needed.
    */
-  g_free (opt_save_file);
-  g_free (opt_display_name);
-  g_free (opt_client_id);
+  free (opt_save_file);
+  free (opt_display_name);
+  free (opt_client_id);
 
   if (!meta_display_open ())
     meta_exit (META_EXIT_ERROR);
-  
+
   g_main_loop_run (meta_main_loop);
 
   meta_finalize ();
@@ -590,6 +668,15 @@ prefs_changed_callback (MetaPreference pref,
       meta_display_set_cursor_theme (meta_prefs_get_cursor_theme (),
 				     meta_prefs_get_cursor_size ());
       break;
+    case META_PREF_SYNC_METHOD:
+      meta_display_update_sync_state (meta_prefs_get_sync_method ());
+      break;
+    case META_PREF_UI_SCALE:
+      meta_ui_set_current_theme (meta_prefs_get_theme (), TRUE);
+      meta_display_retheme_all ();
+      meta_display_set_cursor_theme (meta_prefs_get_cursor_theme (),
+                                     meta_prefs_get_cursor_size ());
+      break;
     default:
       /* handled elsewhere or otherwise */
       break;
