@@ -395,7 +395,7 @@ meta_stack_tracker_free (MetaStackTracker *tracker)
   g_queue_free (tracker->queued_requests);
   tracker->queued_requests = NULL;
 
-  g_free (tracker);
+  free (tracker);
 }
 
 static void
@@ -739,7 +739,7 @@ meta_stack_tracker_queue_sync_stack (MetaStackTracker *tracker)
 {
   if (tracker->sync_stack_later == 0)
     {
-      tracker->sync_stack_later = meta_later_add (META_LATER_BEFORE_REDRAW,
+      tracker->sync_stack_later = meta_later_add (META_LATER_SYNC_STACK,
                                                   stack_tracker_sync_stack_later,
                                                   tracker, NULL);
     }
