@@ -226,9 +226,6 @@ struct _MetaWindow
   /* Whether the urgent flag of WM_HINTS is set */
   guint wm_hints_urgent : 1;
 
-  /* Whether we have to fullscreen after placement */
-  guint fullscreen_after_placement : 1;
-
   /* Area to cover when in fullscreen mode.  If _NET_WM_FULLSCREEN_MONITORS has
    * been overridden (via a client message), the window will cover the union of
    * these monitors.  If not, this is the single monitor which the window's
